# Generated by Django 3.1.1 on 2021-01-25 18:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0007_name_fields'),
    ]

    operations = [
        migrations.RenameField(
            model_name='server',
            old_name='objectSid',
            new_name='objectSidString',
        ),
        migrations.RenameField(
            model_name='workstation',
            old_name='objectSid',
            new_name='objectSidString',
        ),
        migrations.RenameField(
            model_name='user',
            old_name='objectSid',
            new_name='objectSidString',
        ),
        migrations.AddField(
            model_name='user',
            name='objectSid',
            field=models.BinaryField(),
        ),
        migrations.AddField(
            model_name='server',
            name='objectSid',
            field=models.BinaryField(),
        ),
        migrations.AddField(
            model_name='workstation',
            name='objectSid',
            field=models.BinaryField(),
        ),
    ]
