# Generated by Django 3.1.1 on 2020-10-01 14:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0005_directory_related_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='manager',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='ad_import.user', verbose_name='Leder'),
        ),
    ]
