# Generated by Django 3.1.1 on 2020-11-26 15:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0006_manager_set_null'),
    ]

    operations = [
        migrations.AddField(
            model_name='directory',
            name='dns_name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Domain name'),
        ),
        migrations.AddField(
            model_name='directory',
            name='short_name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Domain name (pre-Windows 2000)'),
        ),
    ]
