# Generated by Django 3.1 on 2020-09-18 20:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0004_target_choices'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='directory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='users', to='ad_import.directory'),
        ),
    ]
